@@ -1,7 +1,7 @@
 import sys
 from typing import Optional
 
-from algos import *
+from data_sorter.algos import *
 
 sys.setrecursionlimit(10 ** 6)
 
@@ -30,8 +30,8 @@ def get_comparision(arr: list, algo_names: Optional[list]=[]) -> dict:
         result[algo_name] = getattr(sys.modules[__name__], algo_name)(arr)
     return result
 
-if __name__=='__main__':
-    arr = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
-    # print(get_comparision(arr))
-    print(get_comparision(arr, ['bubble_sort', 'insertion_sort']))
-    print(get_comparision(arr, ['bubble_sort', 'insertion_sort', 'selection_sort']))
\ No newline at end of file
+# if __name__=='__main__':
+#     arr = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
+#     # print(get_comparision(arr))
+#     print(get_comparision(arr, ['bubble_sort', 'insertion_sort']))
+#     print(get_comparision(arr, ['bubble_sort', 'insertion_sort', 'selection_sort']))
\ No newline at end of file
